@@ -120,7 +120,7 @@ def _check_require_part(setting_name, setting_value):
 def _check_parsers(setting_name, setting_value):
     """Returns `True` if the provided list of parsers contains valid values"""
     existing_parsers = [
-        'timestamp', 'relative-time', 'custom-formats', 'absolute-time', 'no-spaces-time'
+        'timestamp', 'relative-time', 'custom-formats', 'absolute-time', 'no-spaces-time', 'negative-timestamp'
     ]  # FIXME: Extract the list of existing parsers from another place (#798)
     unknown_parsers = set(setting_value) - set(existing_parsers)
     if unknown_parsers:
