@@ -2,88 +2,89 @@ info = {
     "name": "de",
     "date_order": "DMY",
     "january": [
-        "januar",
         "jan",
+        "januar",
         "Jänner"
     ],
     "february": [
-        "februar",
         "feb",
+        "februar",
         "Feber"
     ],
     "march": [
-        "märz",
         "mär",
+        "märz",
         "Mrz"
     ],
     "april": [
-        "april",
-        "apr"
+        "apr",
+        "april"
     ],
     "may": [
         "mai"
     ],
     "june": [
-        "juni",
-        "jun"
+        "jun",
+        "juni"
     ],
     "july": [
-        "juli",
-        "jul"
+        "jul",
+        "juli"
     ],
     "august": [
-        "august",
-        "aug"
+        "aug",
+        "august"
     ],
     "september": [
-        "september",
-        "sep"
+        "sep",
+        "sept",
+        "september"
     ],
     "october": [
-        "oktober",
-        "okt"
+        "okt",
+        "oktober"
     ],
     "november": [
-        "november",
-        "nov"
+        "nov",
+        "november"
     ],
     "december": [
-        "dezember",
-        "dez"
+        "dez",
+        "dezember"
     ],
     "monday": [
-        "montag",
         "mo",
+        "montag",
         "Mon"
     ],
     "tuesday": [
-        "dienstag",
         "di",
+        "dienstag",
         "Die"
     ],
     "wednesday": [
-        "mittwoch",
         "mi",
+        "mittwoch",
         "Mit"
     ],
     "thursday": [
-        "donnerstag",
         "do",
+        "donnerstag",
         "Don"
     ],
     "friday": [
-        "freitag",
         "fr",
+        "freitag",
         "Fre"
     ],
     "saturday": [
-        "samstag",
         "sa",
+        "samstag",
         "Sam"
     ],
     "sunday": [
-        "sonntag",
         "so",
+        "sonntag",
         "Son"
     ],
     "am": [
@@ -93,20 +94,20 @@ info = {
         "nachm"
     ],
     "year": [
-        "jahr",
         "j",
+        "jahr",
         "Jahre",
         "Jahren"
     ],
     "month": [
-        "monat",
         "m",
+        "monat",
         "Monate",
         "Monaten"
     ],
     "week": [
-        "woche",
         "w",
+        "woche",
         "Wochen"
     ],
     "day": [
@@ -115,66 +116,66 @@ info = {
         "Tagen"
     ],
     "hour": [
-        "stunde",
         "std",
+        "stunde",
         "Stunden"
     ],
     "minute": [
-        "minute",
         "min",
+        "minute",
         "Minuten"
     ],
     "second": [
-        "sekunde",
         "sek",
+        "sekunde",
         "Sekunden"
     ],
     "relative-type": {
-        "1 year ago": [
-            "letztes jahr"
-        ],
-        "0 year ago": [
-            "dieses jahr"
-        ],
-        "in 1 year": [
-            "nächstes jahr"
-        ],
-        "1 month ago": [
-            "letzten monat"
-        ],
-        "0 month ago": [
-            "diesen monat"
-        ],
-        "in 1 month": [
-            "nächsten monat"
-        ],
-        "1 week ago": [
-            "letzte woche"
-        ],
-        "0 week ago": [
-            "diese woche"
-        ],
-        "in 1 week": [
-            "nächste woche"
-        ],
-        "1 day ago": [
-            "gestern"
-        ],
         "0 day ago": [
             "heute"
         ],
-        "in 1 day": [
-            "morgen"
-        ],
         "0 hour ago": [
             "in dieser stunde"
         ],
         "0 minute ago": [
             "in dieser minute"
         ],
+        "0 month ago": [
+            "diesen monat"
+        ],
         "0 second ago": [
             "jetzt"
         ],
+        "0 week ago": [
+            "diese woche"
+        ],
+        "0 year ago": [
+            "dieses jahr"
+        ],
+        "1 day ago": [
+            "gestern"
+        ],
+        "1 month ago": [
+            "letzten monat"
+        ],
+        "1 week ago": [
+            "letzte woche"
+        ],
+        "1 year ago": [
+            "letztes jahr"
+        ],
+        "in 1 day": [
+            "morgen"
+        ],
+        "in 1 month": [
+            "nächsten monat"
+        ],
+        "in 1 week": [
+            "nächste woche"
+        ],
+        "in 1 year": [
+            "nächstes jahr"
+        ],
         "2 day ago": [
             "vorgestern"
         ],
@@ -183,122 +184,122 @@ info = {
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "in (\\d+) jahr",
-            "in (\\d+) jahren"
-        ],
-        "\\1 year ago": [
-            "vor (\\d+) jahr",
-            "vor (\\d+) jahren"
-        ],
-        "in \\1 month": [
-            "in (\\d+) monat",
-            "in (\\d+) monaten"
-        ],
-        "\\1 month ago": [
-            "vor (\\d+) monat",
-            "vor (\\d+) monaten"
-        ],
-        "in \\1 week": [
-            "in (\\d+) woche",
-            "in (\\d+) wochen",
-            "in (\\d+) wo"
-        ],
-        "\\1 week ago": [
-            "vor (\\d+) woche",
-            "vor (\\d+) wochen",
-            "vor (\\d+) wo"
-        ],
-        "in \\1 day": [
-            "in (\\d+) tag",
-            "in (\\d+) tagen"
-        ],
         "\\1 day ago": [
-            "vor (\\d+) tag",
-            "vor (\\d+) tagen"
-        ],
-        "in \\1 hour": [
-            "in (\\d+) stunde",
-            "in (\\d+) stunden",
-            "in (\\d+) std"
+            "vor (\\d+[.,]?\\d*) tag",
+            "vor (\\d+[.,]?\\d*) tagen"
         ],
         "\\1 hour ago": [
-            "vor (\\d+) stunde",
-            "vor (\\d+) stunden",
-            "vor (\\d+) std",
-            "vor (\\d+)\\s*h"
-        ],
-        "in \\1 minute": [
-            "in (\\d+) minute",
-            "in (\\d+) minuten",
-            "in (\\d+) min",
-            "in (\\d+) m"
+            "vor (\\d+[.,]?\\d*) std",
+            "vor (\\d+[.,]?\\d*) stunde",
+            "vor (\\d+[.,]?\\d*) stunden",
+            "vor (\\d+[.,]?\\d*)\\s*h"
         ],
         "\\1 minute ago": [
-            "vor (\\d+) minute",
-            "vor (\\d+) minuten",
-            "vor (\\d+) min",
-            "vor (\\d+) m",
-            "vor (\\d+)\\s*m"
+            "vor (\\d+[.,]?\\d*) m",
+            "vor (\\d+[.,]?\\d*) min",
+            "vor (\\d+[.,]?\\d*) minute",
+            "vor (\\d+[.,]?\\d*) minuten",
+            "vor (\\d+[.,]?\\d*)\\s*m"
         ],
-        "in \\1 second": [
-            "in (\\d+) sekunde",
-            "in (\\d+) sekunden",
-            "in (\\d+) sek",
-            "in (\\d+) s"
+        "\\1 month ago": [
+            "vor (\\d+[.,]?\\d*) monat",
+            "vor (\\d+[.,]?\\d*) monaten"
         ],
         "\\1 second ago": [
-            "vor (\\d+) sekunde",
-            "vor (\\d+) sekunden",
-            "vor (\\d+) sek",
-            "vor (\\d+) s",
-            "vor (\\d+)\\s*s"
+            "vor (\\d+[.,]?\\d*) s",
+            "vor (\\d+[.,]?\\d*) sek",
+            "vor (\\d+[.,]?\\d*) sekunde",
+            "vor (\\d+[.,]?\\d*) sekunden",
+            "vor (\\d+[.,]?\\d*)\\s*s"
+        ],
+        "\\1 week ago": [
+            "vor (\\d+[.,]?\\d*) wo",
+            "vor (\\d+[.,]?\\d*) woche",
+            "vor (\\d+[.,]?\\d*) wochen"
+        ],
+        "\\1 year ago": [
+            "vor (\\d+[.,]?\\d*) jahr",
+            "vor (\\d+[.,]?\\d*) jahren"
+        ],
+        "in \\1 day": [
+            "in (\\d+[.,]?\\d*) tag",
+            "in (\\d+[.,]?\\d*) tagen"
+        ],
+        "in \\1 hour": [
+            "in (\\d+[.,]?\\d*) std",
+            "in (\\d+[.,]?\\d*) stunde",
+            "in (\\d+[.,]?\\d*) stunden"
+        ],
+        "in \\1 minute": [
+            "in (\\d+[.,]?\\d*) m",
+            "in (\\d+[.,]?\\d*) min",
+            "in (\\d+[.,]?\\d*) minute",
+            "in (\\d+[.,]?\\d*) minuten"
+        ],
+        "in \\1 month": [
+            "in (\\d+[.,]?\\d*) monat",
+            "in (\\d+[.,]?\\d*) monaten"
+        ],
+        "in \\1 second": [
+            "in (\\d+[.,]?\\d*) s",
+            "in (\\d+[.,]?\\d*) sek",
+            "in (\\d+[.,]?\\d*) sekunde",
+            "in (\\d+[.,]?\\d*) sekunden"
+        ],
+        "in \\1 week": [
+            "in (\\d+[.,]?\\d*) wo",
+            "in (\\d+[.,]?\\d*) woche",
+            "in (\\d+[.,]?\\d*) wochen"
+        ],
+        "in \\1 year": [
+            "in (\\d+[.,]?\\d*) jahr",
+            "in (\\d+[.,]?\\d*) jahren"
         ]
     },
     "locale_specific": {
-        "de-LU": {
-            "name": "de-LU"
-        },
         "de-AT": {
             "name": "de-AT",
             "january": [
-                "jänner",
-                "jän"
+                "jän",
+                "jänner"
             ]
         },
-        "de-CH": {
-            "name": "de-CH"
-        },
-        "de-LI": {
-            "name": "de-LI"
-        },
         "de-BE": {
             "name": "de-BE"
         },
+        "de-CH": {
+            "name": "de-CH"
+        },
         "de-IT": {
             "name": "de-IT",
             "january": [
-                "jänner",
-                "jän"
+                "jän",
+                "jänner"
             ]
+        },
+        "de-LI": {
+            "name": "de-LI"
+        },
+        "de-LU": {
+            "name": "de-LU"
         }
     },
     "skip": [
-        "um",
-        "uhr",
         "etwa",
+        "uhr",
+        "um",
         "und",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "sentence_splitter_group": 1,
