@@ -2,80 +2,80 @@ info = {
     "name": "nyn",
     "date_order": "DMY",
     "january": [
-        "okwokubanza",
-        "kbz"
+        "kbz",
+        "okwokubanza"
     ],
     "february": [
-        "okwakabiri",
-        "kbr"
+        "kbr",
+        "okwakabiri"
     ],
     "march": [
-        "okwakashatu",
-        "kst"
+        "kst",
+        "okwakashatu"
     ],
     "april": [
-        "okwakana",
-        "kkn"
+        "kkn",
+        "okwakana"
     ],
     "may": [
-        "okwakataana",
-        "ktn"
+        "ktn",
+        "okwakataana"
     ],
     "june": [
-        "okwamukaaga",
-        "kmk"
+        "kmk",
+        "okwamukaaga"
     ],
     "july": [
-        "okwamushanju",
-        "kms"
+        "kms",
+        "okwamushanju"
     ],
     "august": [
-        "okwamunaana",
-        "kmn"
+        "kmn",
+        "okwamunaana"
     ],
     "september": [
-        "okwamwenda",
-        "kmw"
+        "kmw",
+        "okwamwenda"
     ],
     "october": [
-        "okwaikumi",
-        "kkm"
+        "kkm",
+        "okwaikumi"
     ],
     "november": [
-        "okwaikumi na kumwe",
-        "knk"
+        "knk",
+        "okwaikumi na kumwe"
     ],
     "december": [
-        "okwaikumi na ibiri",
-        "knb"
+        "knb",
+        "okwaikumi na ibiri"
     ],
     "monday": [
-        "orwokubanza",
-        "ork"
+        "ork",
+        "orwokubanza"
     ],
     "tuesday": [
-        "orwakabiri",
-        "okb"
+        "okb",
+        "orwakabiri"
     ],
     "wednesday": [
-        "orwakashatu",
-        "oks"
+        "oks",
+        "orwakashatu"
     ],
     "thursday": [
-        "orwakana",
-        "okn"
+        "okn",
+        "orwakana"
     ],
     "friday": [
-        "orwakataano",
-        "okt"
+        "okt",
+        "orwakataano"
     ],
     "saturday": [
-        "orwamukaaga",
-        "omk"
+        "omk",
+        "orwamukaaga"
     ],
     "sunday": [
-        "sande",
-        "san"
+        "san",
+        "sande"
     ],
     "am": [
         "am"
@@ -105,65 +105,65 @@ info = {
         "obucweka/esekendi"
     ],
     "relative-type": {
-        "1 year ago": [
-            "last year"
-        ],
-        "0 year ago": [
-            "this year"
-        ],
-        "in 1 year": [
-            "next year"
-        ],
-        "1 month ago": [
-            "last month"
-        ],
-        "0 month ago": [
-            "this month"
-        ],
-        "in 1 month": [
-            "next month"
-        ],
-        "1 week ago": [
-            "last week"
-        ],
-        "0 week ago": [
-            "this week"
-        ],
-        "in 1 week": [
-            "next week"
-        ],
-        "1 day ago": [
-            "nyomwabazyo"
-        ],
         "0 day ago": [
             "erizooba"
         ],
-        "in 1 day": [
-            "nyenkyakare"
-        ],
         "0 hour ago": [
             "this hour"
         ],
         "0 minute ago": [
             "this minute"
         ],
+        "0 month ago": [
+            "this month"
+        ],
         "0 second ago": [
             "now"
+        ],
+        "0 week ago": [
+            "this week"
+        ],
+        "0 year ago": [
+            "this year"
+        ],
+        "1 day ago": [
+            "nyomwabazyo"
+        ],
+        "1 month ago": [
+            "last month"
+        ],
+        "1 week ago": [
+            "last week"
+        ],
+        "1 year ago": [
+            "last year"
+        ],
+        "in 1 day": [
+            "nyenkyakare"
+        ],
+        "in 1 month": [
+            "next month"
+        ],
+        "in 1 week": [
+            "next week"
+        ],
+        "in 1 year": [
+            "next year"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
