@@ -215,76 +215,76 @@ info = {
     },
     "relative-type-regex": {
         "\\1 day ago": [
-            "(\\d+) д назад",
-            "(\\d+) день назад",
-            "(\\d+) дн назад",
-            "(\\d+) дня назад"
+            "(\\d+[.,]?\\d*) д назад",
+            "(\\d+[.,]?\\d*) день назад",
+            "(\\d+[.,]?\\d*) дн назад",
+            "(\\d+[.,]?\\d*) дня назад"
         ],
         "\\1 hour ago": [
-            "(\\d+) ч назад",
-            "(\\d+) час назад",
-            "(\\d+) часа назад"
+            "(\\d+[.,]?\\d*) ч назад",
+            "(\\d+[.,]?\\d*) час назад",
+            "(\\d+[.,]?\\d*) часа назад"
         ],
         "\\1 minute ago": [
-            "(\\d+) мин назад",
-            "(\\d+) минуту назад",
-            "(\\d+) минуты назад"
+            "(\\d+[.,]?\\d*) мин назад",
+            "(\\d+[.,]?\\d*) минуту назад",
+            "(\\d+[.,]?\\d*) минуты назад"
         ],
         "\\1 month ago": [
-            "(\\d+) мес назад",
-            "(\\d+) месяц назад",
-            "(\\d+) месяца назад"
+            "(\\d+[.,]?\\d*) мес назад",
+            "(\\d+[.,]?\\d*) месяц назад",
+            "(\\d+[.,]?\\d*) месяца назад"
         ],
         "\\1 second ago": [
-            "(\\d+) сек назад",
-            "(\\d+) секунду назад",
-            "(\\d+) секунды назад"
+            "(\\d+[.,]?\\d*) сек назад",
+            "(\\d+[.,]?\\d*) секунду назад",
+            "(\\d+[.,]?\\d*) секунды назад"
         ],
         "\\1 week ago": [
-            "(\\d+) нед назад",
-            "(\\d+) недели назад",
-            "(\\d+) неделю назад"
+            "(\\d+[.,]?\\d*) нед назад",
+            "(\\d+[.,]?\\d*) недели назад",
+            "(\\d+[.,]?\\d*) неделю назад"
         ],
         "\\1 year ago": [
-            "(\\d+) г назад",
-            "(\\d+) год назад",
-            "(\\d+) года назад"
+            "(\\d+[.,]?\\d*) г назад",
+            "(\\d+[.,]?\\d*) год назад",
+            "(\\d+[.,]?\\d*) года назад"
         ],
         "in \\1 day": [
-            "через (\\d+) д",
-            "через (\\d+) день",
-            "через (\\d+) дн",
-            "через (\\d+) дня"
+            "через (\\d+[.,]?\\d*) д",
+            "через (\\d+[.,]?\\d*) день",
+            "через (\\d+[.,]?\\d*) дн",
+            "через (\\d+[.,]?\\d*) дня"
         ],
         "in \\1 hour": [
-            "через (\\d+) ч",
-            "через (\\d+) час",
-            "через (\\d+) часа"
+            "через (\\d+[.,]?\\d*) ч",
+            "через (\\d+[.,]?\\d*) час",
+            "через (\\d+[.,]?\\d*) часа"
         ],
         "in \\1 minute": [
-            "через (\\d+) мин",
-            "через (\\d+) минуту",
-            "через (\\d+) минуты"
+            "через (\\d+[.,]?\\d*) мин",
+            "через (\\d+[.,]?\\d*) минуту",
+            "через (\\d+[.,]?\\d*) минуты"
         ],
         "in \\1 month": [
-            "через (\\d+) мес",
-            "через (\\d+) месяц",
-            "через (\\d+) месяца"
+            "через (\\d+[.,]?\\d*) мес",
+            "через (\\d+[.,]?\\d*) месяц",
+            "через (\\d+[.,]?\\d*) месяца"
         ],
         "in \\1 second": [
-            "через (\\d+) сек",
-            "через (\\d+) секунду",
-            "через (\\d+) секунды"
+            "через (\\d+[.,]?\\d*) сек",
+            "через (\\d+[.,]?\\d*) секунду",
+            "через (\\d+[.,]?\\d*) секунды"
         ],
         "in \\1 week": [
-            "через (\\d+) нед",
-            "через (\\d+) недели",
-            "через (\\d+) неделю"
+            "через (\\d+[.,]?\\d*) нед",
+            "через (\\d+[.,]?\\d*) недели",
+            "через (\\d+[.,]?\\d*) неделю"
         ],
         "in \\1 year": [
-            "через (\\d+) г",
-            "через (\\d+) год",
-            "через (\\d+) года"
+            "через (\\d+[.,]?\\d*) г",
+            "через (\\d+[.,]?\\d*) год",
+            "через (\\d+[.,]?\\d*) года"
         ]
     },
     "locale_specific": {
